@@ -1,5 +1,6 @@
 import qrunner
 from qrunner import Elem
+from qrunner.core.image.element import ImageElem
 
 
 class HomePage(qrunner.Page):
@@ -20,9 +21,9 @@ class PatentSearch(qrunner.Page):
     create_tech = Elem(image='patent_create_tech_title.png', desc='创建技术报告标题')
 
     def go_tech_report(self):
-        self.elem(self.report_entry).click()
-        self.elem(self.tech_report).click()
-        assert self.elem(self.create_tech).exists()
+        ImageElem(self.driver, **self.report_entry).click()
+        ImageElem(self.driver, **self.tech_report).click()
+        assert ImageElem(self.driver, **self.create_tech).exists()
 
 
 class TestSearch(qrunner.TestCase):
