@@ -291,6 +291,17 @@ class TestCase(HttpRequest):
                 actual_code == status_code
         ), f"status_code {ResponseResult} != {status_code}"
 
+    @staticmethod
+    def assertStatusCode(status_code):
+        """
+        兼容历史版本
+        """
+        actual_code = ResponseResult.status_code
+        logger.info(f"断言: {actual_code} 等于 {status_code}")
+        assert (
+                actual_code == status_code
+        ), f"status_code {ResponseResult} != {status_code}"
+
     @staticmethod
     def assert_schema(schema, response=None) -> None:
         """
@@ -317,6 +328,24 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 等于 {value}")
         assert search_value == value, f"{search_value} != {value}"
 
+    @staticmethod
+    def assertEq(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 等于 {value}")
+        assert search_value == value, f"{search_value} != {value}"
+
+    @staticmethod
+    def assertPath(path, value):
+        """
+        兼容历史版本，同assert_eq
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 等于 {value}")
+        assert search_value == value, f"{search_value} != {value}"
+
     @staticmethod
     def assert_not_eq(path, value):
         """
@@ -327,6 +356,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 不等于 {value}")
         assert search_value != value, f"{search_value} 等于 {value}"
 
+    @staticmethod
+    def assertNotEq(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 不等于 {value}")
+        assert search_value != value, f"{search_value} 等于 {value}"
+
     @staticmethod
     def assert_len_eq(path, value):
         """
@@ -337,6 +375,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {len(search_value)} 等于 {value}")
         assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
 
+    @staticmethod
+    def assertLenEq(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {len(search_value)} 等于 {value}")
+        assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
+
     @staticmethod
     def assert_len_gt(path, value):
         """
@@ -347,6 +394,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {len(search_value)} 大于 {value}")
         assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
 
+    @staticmethod
+    def assertLenGt(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {len(search_value)} 大于 {value}")
+        assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
+
     @staticmethod
     def assert_len_gt_or_eq(path, value):
         """
@@ -357,6 +413,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {len(search_value)} 大于等于 {value}")
         assert len(search_value) >= value, f"{search_value} 的长度不大于 {value}"
 
+    @staticmethod
+    def assertLenGtOrEq(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {len(search_value)} 大于等于 {value}")
+        assert len(search_value) >= value, f"{search_value} 的长度不大于 {value}"
+
     @staticmethod
     def assert_len_lt(path, value):
         """
@@ -367,6 +432,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {len(search_value)} 小于 {value}")
         assert len(search_value) < value, f"{search_value} 的长度不大于 {value}"
 
+    @staticmethod
+    def assertLenLt(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {len(search_value)} 小于 {value}")
+        assert len(search_value) < value, f"{search_value} 的长度不大于 {value}"
+
     @staticmethod
     def assert_len_lt_or_eq(path, value):
         """
@@ -377,6 +451,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {len(search_value)} 小于等于 {value}")
         assert len(search_value) <= value, f"{search_value} 的长度不大于 {value}"
 
+    @staticmethod
+    def assertLenLtOrEq(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {len(search_value)} 小于等于 {value}")
+        assert len(search_value) <= value, f"{search_value} 的长度不大于 {value}"
+
     @staticmethod
     def assert_gt(path, value):
         """
@@ -392,6 +475,20 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 大于 {value}")
         assert search_value > value, f"{search_value} 不大于 {value}"
 
+    @staticmethod
+    def assertGt(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if "." in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f"断言: {search_value} 大于 {value}")
+        assert search_value > value, f"{search_value} 不大于 {value}"
+
     @staticmethod
     def assert_gt_or_eq(path, value):
         """
@@ -407,6 +504,20 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 大于等于 {value}")
         assert search_value >= value, f"{search_value} 小于 {value}"
 
+    @staticmethod
+    def assertGtOrEq(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if "." in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f"断言: {search_value} 大于等于 {value}")
+        assert search_value >= value, f"{search_value} 小于 {value}"
+
     @staticmethod
     def assert_lt(path, value):
         """
@@ -422,6 +533,20 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 小于 {value}")
         assert search_value < value, f"{search_value} 不大于 {value}"
 
+    @staticmethod
+    def assertLt(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if "." in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f"断言: {search_value} 小于 {value}")
+        assert search_value < value, f"{search_value} 不大于 {value}"
+
     @staticmethod
     def assert_lt_or_eq(path, value):
         """
@@ -437,6 +562,20 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 小于等于 {value}")
         assert search_value <= value, f"{search_value} 不大于 {value}"
 
+    @staticmethod
+    def assertLtOrEq(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if "." in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f"断言: {search_value} 小于等于 {value}")
+        assert search_value <= value, f"{search_value} 不大于 {value}"
+
     @staticmethod
     def assert_range(path, start, end):
         """值在(start, end)范围内
@@ -453,6 +592,21 @@ class TestCase(HttpRequest):
                 search_value <= end
         ), f"{search_value} 不在[{start}, {end}]范围内"
 
+    @staticmethod
+    def assertRange(path, start, end):
+        """兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            if "." in search_value:
+                search_value = float(search_value)
+            else:
+                search_value = int(search_value)
+        logger.info(f"断言: {search_value} 在 [{start}, {end}] 范围内")
+        assert (search_value >= start) & (
+                search_value <= end
+        ), f"{search_value} 不在[{start}, {end}]范围内"
+
     @staticmethod
     def assert_in(path, value):
         """
@@ -463,6 +617,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 被 {value} 包含")
         assert search_value in value, f"{value} 不包含 {search_value}"
 
+    @staticmethod
+    def assertIn(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 被 {value} 包含")
+        assert search_value in value, f"{value} 不包含 {search_value}"
+
     @staticmethod
     def assert_not_in(path, value):
         """
@@ -473,6 +636,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 不被 {value} 包含")
         assert search_value not in value, f"{value} 包含 {search_value}"
 
+    @staticmethod
+    def assertNotIn(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 不被 {value} 包含")
+        assert search_value not in value, f"{value} 包含 {search_value}"
+
     @staticmethod
     def assert_not_exists(path):
         """断言字段不存在"""
@@ -480,6 +652,13 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {path} 不存在或值为None")
         assert search_value is None, f"仍然包含 {path} 为 {search_value}"
 
+    @staticmethod
+    def assertNotExists(path):
+        """兼容历史版本"""
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {path} 不存在或值为None")
+        assert search_value is None, f"仍然包含 {path} 为 {search_value}"
+
     @staticmethod
     def assert_contain(path, value):
         """
@@ -490,6 +669,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 包含 {value}")
         assert value in search_value, f"{search_value} 不包含 {value}"
 
+    @staticmethod
+    def assertContain(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 包含 {value}")
+        assert value in search_value, f"{search_value} 不包含 {value}"
+
     @staticmethod
     def assert_not_contain(path, value):
         """
@@ -500,6 +688,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 不包含 {value}")
         assert value not in search_value, f"{search_value} 包含 {value}"
 
+    @staticmethod
+    def assertNotContain(path, value):
+        """
+        兼容历史版本
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 不包含 {value}")
+        assert value not in search_value, f"{search_value} 包含 {value}"
+
     @staticmethod
     def assert_type_match(path, value_type):
         """
@@ -524,6 +721,29 @@ class TestCase(HttpRequest):
             search_value, value_type
         ), f"{search_value} 不是 {value_type} 类型"
 
+    @staticmethod
+    def assertTypeMatch(path, value_type):
+        """
+        兼容历史版本
+        """
+        if not isinstance(value_type, type):
+            if value_type == "int":
+                value_type = int
+            elif value_type == "str":
+                value_type = str
+            elif value_type == "list":
+                value_type = list
+            elif value_type == "dict":
+                value_type = dict
+            else:
+                value_type = str
+
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 是 {value_type} 类型")
+        assert isinstance(
+            search_value, value_type
+        ), f"{search_value} 不是 {value_type} 类型"
+
     @staticmethod
     def assert_starts_with(path, value):
         """
@@ -534,6 +754,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 以 {value} 开头")
         assert search_value.startswith(value), f"{search_value} 不以 {value} 开头"
 
+    @staticmethod
+    def assertStartsWith(path, value):
+        """
+        兼容历史版本
+        """
+        search_value: str = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 以 {value} 开头")
+        assert search_value.startswith(value), f"{search_value} 不以 {value} 开头"
+
     @staticmethod
     def assert_ends_with(path, value):
         """
@@ -544,6 +773,15 @@ class TestCase(HttpRequest):
         logger.info(f"断言: {search_value} 以 {value} 结尾")
         assert search_value.endswith(value), f"{search_value} 不以 {value} 结尾"
 
+    @staticmethod
+    def assertEndsWith(path, value):
+        """
+        兼容历史版本
+        """
+        search_value: str = jmespath.search(path, ResponseResult.response)
+        logger.info(f"断言: {search_value} 以 {value} 结尾")
+        assert search_value.endswith(value), f"{search_value} 不以 {value} 结尾"
+
     @staticmethod
     def assert_regex_match(path, value):
         """
@@ -554,3 +792,11 @@ class TestCase(HttpRequest):
         match_obj = re.match(r"" + value, search_value, flags=re.I)
         logger.info(f"断言: {search_value} 匹配正则表达式 {value} 成功")
         assert match_obj is not None, f"结果 {search_value} 匹配失败"
+
+    @staticmethod
+    def assertRegexMatch(path, value):
+        """同assert_regex_match，兼容历史版本"""
+        search_value = jmespath.search(path, ResponseResult.response)
+        match_obj = re.match(r"" + value, search_value, flags=re.I)
+        logger.info(f"断言: {search_value} 匹配正则表达式 {value} 成功")
+        assert match_obj is not None, f"结果 {search_value} 匹配失败"
