@@ -3,8 +3,9 @@ import argparse
 from webdriver_manager.firefox import GeckoDriverManager
 from webdriver_manager.microsoft import EdgeChromiumDriverManager, IEDriverManager
 
-from qrunner import __description__, __version__, logger
+from qrunner.utils.log import logger
 from qrunner.scaffold import create_scaffold
+from qrunner import __version__, __description__
 from qrunner.utils.webdriver_manager_extend import ChromeDriverManager
 
 
@@ -14,9 +15,6 @@ def main():
     parser.add_argument(
         "-v", "--version", dest="version", action="store_true", help="版本号"
     )
-    parser.add_argument(
-        "-n", "--project_name", dest="project_name", help="项目名称，用于创建demo"
-    )
     parser.add_argument(
         "-p", "--platform", dest="platform", help="所属平台，android、ios、web、api，用于创建demo"
     )
@@ -26,18 +24,14 @@ def main():
 
     args = parser.parse_args()
     version = args.version
-    project = args.project_name
     platform = args.platform
     install = args.install
 
     if version:
         print(__version__)
         return 0
-    if project:
-        if platform:
-            create_scaffold(project, platform)
-        else:
-            print("请输入-p参数设置所属平台")
+    if platform:
+        create_scaffold(platform)
         return 0
     if install:
         install_driver(install)
