@@ -2,9 +2,11 @@ import inspect
 import os
 
 import pytest
-
+from qrunner.running.config import Qrunner
 from qrunner.utils.config import config
 from qrunner.utils.log import logger
+from qrunner.core.android.driver import AndroidDriver
+from qrunner.core.ios.driver import IosDriver
 
 
 class TestMain(object):
@@ -15,6 +17,7 @@ class TestMain(object):
                  platform: str = None,
                  device_id: str = None,
                  pkg_name: str = None,
+                 pkg_url: str = None,
                  browser: str = 'chrome',
                  case_path: str = None,
                  rerun: int = 0,
@@ -30,6 +33,7 @@ class TestMain(object):
         @param platform: 平台，android、ios、web、api
         @param device_id: 设备id，针对安卓和ios
         @param pkg_name: 应用包名，针对安卓和ios
+        @param pkg_url: 应用安装包，针对安卓和ios
         @param browser: 浏览器类型，chrome、firefox、edge、safari
         @param case_path: 用例目录，默认代表当前文件、.代表当前目录
         @param rerun: 失败重试次数
@@ -45,8 +49,20 @@ class TestMain(object):
         """
         # 将数据写入全局变量
         config.set('common', 'platform', platform)
-        config.set('app', 'device_id', device_id)
-        config.set('app', 'pkg_name', pkg_name)
+        if platform == 'android':
+            Qrunner.driver = AndroidDriver(device_id)
+            Qrunner.driver.pkg_name = pkg_name
+            if pkg_url is not None:
+                Qrunner.driver.install_app(pkg_url)
+        elif platform == 'ios':
+            Qrunner.driver = IosDriver(device_id)
+            Qrunner.driver.pkg_name = pkg_name
+            if pkg_url is not None:
+                Qrunner.driver.install_app(pkg_url)
+        # config.set('app', 'device_id', device_id)
+        # config.set('app', 'pkg_name', pkg_name)
+        # Qrunner.pkg_name = pkg_name
+        # Qrunner.pkg_url = pkg_url
         config.set('web', 'browser', browser)
         config.set('common', 'base_url', base_url)
         if headers is not None:
