@@ -6,6 +6,7 @@ import urllib.parse
 import requests
 import json
 from qrunner.utils.allure_data import get_allure_data
+from qrunner.utils.log import logger
 
 
 # 钉钉机器人
@@ -81,7 +82,10 @@ class DingTalk:
             }
         }
 
-        self.send_msg(msg_data)
+        if fail > 0:
+            self.send_msg(msg_data)
+        else:
+            logger.info('用例全部成功，无需通知~')
 
 
 
