@@ -95,7 +95,10 @@ class Mail:
             .format(total, passed, fail, rate, report_url)
 
         # 发送邮件
-        self.send_email(to_list, title, body_str)
+        if fail > 0:
+            self.send_email(to_list, title, body_str)
+        else:
+            logger.info('用例全部成功，无需通知~')
 
 
 if __name__ == '__main__':
